Quick Start
===========

.. include:: ../README.rst
   :start-after: .. contents
   :end-before: .. substitutions


.. substitutions
.. |Sentinel1Etad| replace:: :class:`s1etad.Sentinel1Etad`
.. |Sentinel1EtadSwath| replace:: :class:`s1etad.Sentinel1EtadSwath`
.. |Sentinel1EtadBurst| replace:: :class:`s1etad.Sentinel1EtadBurst`
.. |Sentinel1Etad.burst_catalogue| replace:: :attr:`s1etad.Sentinel1Etad.burst_catalogue`
